@@ -17,11 +17,14 @@
 
 #include "kcheckeduca.h"
 #include "kcheckeduca.moc"
+
 #include <qstyle.h>
+#include <kaccelmanager.h>
 
 KCheckEduca::KCheckEduca(QWidget *parent, const char *name ) : QCheckBox(parent,name)
 {
     _doc = 0;
+    KAcceleratorManager::setNoAccel( this );
 }
 
 KCheckEduca::~KCheckEduca()
@@ -53,7 +56,7 @@ void KCheckEduca::drawButtonLabel( QPainter *p){
     int xo = 0;
     int yo = 0;
 
-    this->resize( this->width(), rh);
+    resize( width(), rh);
 
     yo = (cr.height()-rh)/2;
 
