@@ -1,4 +1,3 @@
-// drgeo-filter.cc
 // Copyright (C)  2004  Pino Toscano <toscano.pino@tiscali.it>
 // Copyright (C)  2004  Dominique Devriese <devriese@kde.org>
 
@@ -14,8 +13,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "drgeo-filter.h"
 
@@ -46,6 +45,7 @@
 #include "../objects/other_type.h"
 #include "../objects/point_imp.h"
 #include "../objects/point_type.h"
+#include "../objects/polygon_type.h"
 #include "../objects/transform_types.h"
 #include "../objects/vector_type.h"
 
@@ -144,7 +144,8 @@ KigDocument* KigFilterDrgeo::load( const QString& file )
 #ifdef DRGEO_DEBUG
         kdDebug() << "- Figure: '" << e.attribute("name") << "'" << endl;
 #endif
-        bool grid = ( e.attribute( "grid" ) != "False" );
+        bool grid = !e.attribute( "grid" ).isEmpty() &&
+                    ( e.attribute( "grid" ) != "False" );
         return importFigure( e.firstChild(), file, grid );
       }
     }
@@ -279,14 +280,12 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         else if ( ce.tagName() == "value" )
           values = ce.text();
       }
-      bool ok;
-      bool ok2;
-      bool ok3;
-      double x = xs.toDouble( &ok );
-      double y = ys.toDouble( &ok2 );
-      double value = values.toDouble( &ok3 );
       if ( domelem.attribute( "type" ) == "Free" )
       {
+        bool ok;
+        bool ok2;
+        double x = xs.toDouble( &ok );
+        double y = ys.toDouble( &ok2 );
         if ( ! ( ok && ok2 ) )
           KIG_FILTER_PARSE_ERROR;
         oc = fact->fixedPointCalcer( Coordinate( x, y ) );
@@ -309,6 +308,8 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
       }
       else if ( domelem.attribute( "type" ) == "On_curve" )
       {
+        bool ok3;
+        double value = values.toDouble( &ok3 );
         if ( ! ok3 )
           KIG_FILTER_PARSE_ERROR;
         if ( ( parents[0]->imp()->inherits( CircleImp::stype() ) ) ||
@@ -399,7 +400,8 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
              ( domelem.tagName() == "segment" ) ||
              ( domelem.tagName() == "vector" ) ||
              ( domelem.tagName() == "circle" ) ||
-             ( domelem.tagName() == "arcCircle" ) )
+             ( domelem.tagName() == "arcCircle" ) ||
+             ( domelem.tagName() == "polygon" ) )
     {
       const ObjectType* type = 0;
       if ( domelem.attribute( "type" ) == "2pts" )
@@ -457,6 +459,22 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
         }
         oc = new ObjectTypeCalcer( type, parents );
       }
+      else if( domelem.attribute( "type" ) == "npts" )
+      {
+        if( domelem.tagName() == "polygon" )
+        {
+          if ( parents.size() < 3 ) KIG_FILTER_PARSE_ERROR;
+          type = PolygonBNPType::instance();
+        }
+        else
+        {
+          notSupported( file, i18n( "This Dr. Geo file contains a \"%1 %2\" object, "
+                                    "which Kig does not currently support." ).arg( domelem.tagName() ).arg(
+                                    domelem.attribute( "type" ) ) );
+          return false;
+        }
+        oc = new ObjectTypeCalcer( type, parents );
+      }
       else if ( domelem.attribute( "type" ) == "perpendicular" )
         oc = new ObjectTypeCalcer( LinePerpendLPType::instance(), parents );
       else if ( domelem.attribute( "type" ) == "parallel" )
@@ -679,12 +697,6 @@ KigDocument* KigFilterDrgeo::importFigure( QDomNode f, const QString& file, cons
       kdDebug() << "+++++++++ oc:" << oc << endl;
 #endif
     }
-    else if ( domelem.tagName() == "polygon" )
-    {
-      notSupported( file, i18n( "This Dr. Geo file contains a polygon object, "
-                                "which Kig does not currently support." ) );
-      return false;
-    }
     else if ( ( domelem.tagName() == "boundingBox" ) ||
               ( domelem.tagName() == "customUI" ) )
     {
