@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "builtin_stuff.h"
 
@@ -121,7 +121,7 @@ void setupBuiltinStuff()
       I18N_NOOP( "Select the angle you want to construct the bisector of..." ),
       I18N_NOOP( "Angle Bisector" ),
       I18N_NOOP( "The bisector of an angle" ),
-      "angle-bisector",
+      "angle_bisector",
       "angle-bisector" );
     actions->add( new ConstructibleAction( &anglebisectionctor, "objects_new_angle_bisector" ) );
 
@@ -534,8 +534,7 @@ void setupBuiltinStuff()
       I18N_NOOP( "Distance Test" ),
       I18N_NOOP( "Test whether a given point have the same distance from a given point "
                  "and from another given point" ),
-      "test" );
-//      "testdistance" );
+      "testdistance" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_distancetest" ) );
 
