@@ -14,7 +14,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
@@ -25,7 +25,6 @@
 #include "coordinate.h"
 #include "rect.h"
 
-#include <qptrlist.h>
 #include <qrect.h>
 #include <kdeversion.h>
 
@@ -65,11 +64,11 @@ public:
    * Default constructor.  Sets a and b to the origin.
    * \endif
    */
-  LineData() : a(), b() {};
+  LineData() : a(), b() {}
   /**
    * Constructor.  Sets a and b to the given Coordinates.
    */
-  LineData( const Coordinate& na, const Coordinate& nb ) : a( na ), b( nb ) {};
+  LineData( const Coordinate& na, const Coordinate& nb ) : a( na ), b( nb ) {}
   /**
    * One point on the line.
    */
@@ -81,11 +80,11 @@ public:
   /**
    * The direction of the line.  Equivalent to b - a.
    */
-  const Coordinate dir() const { return b - a; };
+  const Coordinate dir() const { return b - a; }
   /**
    * The length from a to b.
    */
-  double length() const { return ( b - a ).length(); };
+  double length() const { return ( b - a ).length(); }
 
   /**
    * Return true if this line is parallel to l.
