@@ -14,13 +14,16 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
 #ifndef KROMAJIEDIT_H
 #define KROMAJIEDIT_H
 
+#include <qmap.h>
+#include <qcstring.h>
+
 #include <klineedit.h>
 
 class QKeyEvent;
