@@ -210,8 +210,11 @@ void KPercentage::startExercise()
     percent_main->setNumber( spin_box_number->value() );
     percent_main->selected_level = combo_box_level->currentItem();
     percent_main->initExercise();
+    QPoint p = pos();
     hide();
+    percent_main->move( p );
     percent_main->exec();
+    move( p );
     show();
 }
 
