@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include <qtabwidget.h>
+#include <qlayout.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -25,6 +26,7 @@
 #include <knumvalidator.h>
 
 #include "kstars.h"
+#include "kstarsdata.h"
 #include "dms.h"
 #include "skypoint.h"
 #include "dmsbox.h"
@@ -36,16 +38,21 @@ FocusDialog::FocusDialog( QWidget *parent )
 	Point = 0; //initialize pointer to null
 	UsedAltAz = false; //assume RA/Dec by default
 
-	fdlg = new FocusDialogDlg(this);
-	setMainWidget(fdlg);
-	this->show();
-        fdlg->epochName->setValidator( new KDoubleValidator( fdlg->epochName ) );
+	QFrame *page = plainPage();
+	setMainWidget(page);
+	QVBoxLayout *vlay = new QVBoxLayout( page, 0, spacingHint() );
+	fdlg = new FocusDialogDlg(page);
+	fdlg->epochName->setValidator( new KDoubleValidator( fdlg->epochName ) );
+	vlay->addWidget( fdlg );
+	
 	connect( fdlg->raBox, SIGNAL(textChanged( const QString & ) ), this, SLOT( checkLineEdits() ) );
 	connect( fdlg->decBox, SIGNAL(textChanged( const QString & ) ), this, SLOT( checkLineEdits() ) );
 	connect( fdlg->azBox, SIGNAL(textChanged( const QString & ) ), this, SLOT( checkLineEdits() ) );
 	connect( fdlg->altBox, SIGNAL(textChanged( const QString & ) ), this, SLOT( checkLineEdits() ) );
 	connect( this, SIGNAL( okClicked() ), this, SLOT( validatePoint() ) );
 
+	fdlg->raBox->setDegType(false); //RA box should be HMS-style
+	fdlg->raBox->setFocus(); //set input focus
 	enableButtonOK( false ); //disable until both lineedits are filled
 }
 
@@ -90,7 +97,7 @@ void FocusDialog::validatePoint() {
 		Point = new SkyPoint( ra, dec );
 		double epoch0 = getEpoch( fdlg->epochName->text() );
 		long double jd0 = epochToJd ( epoch0 );
-		Point->apparentCoord(jd0, ks->data()->currentDate() );
+		Point->apparentCoord(jd0, ks->data()->ut().djd() );
 
 		QDialog::accept();
 	} else {
@@ -152,5 +159,6 @@ QSize FocusDialog::sizeHint() const
 
 void FocusDialog::activateAzAltPage() {
 	fdlg->fdTab->showPage( fdlg->aaTab );
+	fdlg->azBox->setFocus();
 }
 #include "focusdialog.moc"
