@@ -207,7 +207,7 @@ extern XMLEle *readXMLFile (FILE *fp, LilXML *lp, char errmsg[]);
 extern void prXMLEle (FILE *fp, XMLEle *e, int level);
 
 /* install alternatives to malloc/realloc/free */
-extern void xmlMalloc (void *(*newmalloc)(size_t size),
+extern void indi_xmlMalloc (void *(*newmalloc)(size_t size),
     void *(*newrealloc)(void *ptr, size_t size), void (*newfree)(void *ptr));
 
 /*@}*/
@@ -246,7 +246,7 @@ extern void xmlMalloc (void *(*newmalloc)(size_t size),
  */
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile$ $Date: 2005-09-29 16:33:08 +0200 (Do, 29 Sep 2005) $ $Revision: 465369 $ $Name:  $
+ * @(#) $RCSfile$ $Date: 2006-03-09 22:28:31 +0100 (Do, 09 Mär 2006) $ $Revision: 517084 $ $Name:  $
  */
 
 #endif	/* LILXML_H */
