@@ -60,9 +60,9 @@ public:
 		*@param num pointer to the KSNumbers object describing 
 		*the date/time at which to find the positions.
 		*@param jup pointer to the jupiter object
-		*@param sun pointer to the Sun object
+		*@param ksun pointer to the Sun object
 		*/
-	void findPosition( const KSNumbers *num, const KSPlanet *jup, const KSSun *Sun );
+	void findPosition( const KSNumbers *num, const KSPlanet *jup, const KSSun *ksun );
 	
 	/**@return pointer to the stored RA,Dec position of a moon.
 		*@param id which moon?  0=Io, 1=Europa, 2=Ganymede, 3=Callisto
