@@ -42,7 +42,7 @@
 // **************************
 
 KTouchLectureEditor::KTouchLectureEditor(QWidget *parent, const char* name, bool modal, WFlags fl)
- : KTouchEditorDlg(parent, name, modal, fl)
+ : KTouchLectureEditorDlg(parent, name, modal, fl)
 {
     levelListView->setSorting(-1); // don't sort my level list view!
 
@@ -80,7 +80,7 @@ bool KTouchLectureEditor::startEditor(const KURL& url) {
 // *************************
 
 void KTouchLectureEditor::fontBtnClicked() {
-    QFont f;
+    QFont f(m_lecture.m_fontSuggestions);
     if (KFontDialog::getFont(f, false, this, true)==QDialog::Accepted) {
         linesTextEdit->setFont(f);
         lectureCommentEdit->setFont(f);
@@ -88,8 +88,8 @@ void KTouchLectureEditor::fontBtnClicked() {
         newCharsEdit->setFont(f);
         titleEdit->setFont(f);
         levelListView->setFont(f);
-		m_lecture.m_fontSuggestions = f.toString();
-		setModified();
+        m_lecture.m_fontSuggestions = f.family();
+        setModified();
     }
 }
 // -----------------------------------------------------------------------------
@@ -112,7 +112,7 @@ void KTouchLectureEditor::saveBtnClicked() {
 
 void KTouchLectureEditor::saveAsBtnClicked() {
     QString tmp = KFileDialog::getSaveFileName(QString::null, 
-        "*.ktouch.xml|KTouch Lecture Files\n*.*|All Files", this, i18n("Save Training Lecture") );
+        "*.ktouch.xml|KTouch Lecture Files(*.ktouch.xml)\n*.*|All Files", this, i18n("Save Training Lecture") );
     if (!tmp.isEmpty()) {
         transfer_from_dialog();
         m_currentURL = tmp;
@@ -283,7 +283,7 @@ void KTouchLectureEditor::transfer_to_dialog() {
     }
 	// finally the font
 	if (!m_lecture.m_fontSuggestions.isEmpty()) {
-    	QFont f;
+    	QFont f("Monospace");
 		// TODO : multiple font suggestions
 		f.fromString(m_lecture.m_fontSuggestions);
         linesTextEdit->setFont(f);
@@ -411,7 +411,7 @@ bool KTouchLectureEditor::saveModified() {
     if (!m_modified) return true;
     // ok, ask the user to save the changes
     int result = KMessageBox::questionYesNoCancel(this, 
-        i18n("The lecture has been changed. Do you want to save the changes?"));
+        i18n("The lecture has been changed. Do you want to save the changes?"),QString::null,KStdGuiItem::save(),KStdGuiItem::discard());
     if (result == KMessageBox::Cancel) return false; // User aborted
     if (result == KMessageBox::Yes) saveBtnClicked();
     // if successfully saved the modified flag will be resetted in the saveBtnClicked() function
