@@ -13,14 +13,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-// This file is originally written by Walter Scheppers, but allmost
+// This file is originally written by Walter Scheppers, but almost
 // every aspect of it is slightly changed by Cies Breijs.
   
  
 #include <unistd.h> // for usleep();
+#include <stdlib.h>
 
 #include <qtimer.h>
 
