@@ -20,8 +20,7 @@
 
 #include <klocale.h>
 
-#include "kverbosdoc.h"
-#include <qerfassen.h>
+#include "qerfassen.h"
 #include "verbspanish.h"
 
 class QLineEdit;
