@@ -1,17 +1,14 @@
 /***************************************************************************
 
-    $Id: kvoctrain.cpp,v 1.66 2004/07/13 13:35:25 annma Exp $
-
                       main part of kvoctrain
 
     -----------------------------------------------------------------------
 
-    begin                : Thu Mar 11 20:50:53 MET 1999
+    begin          : Thu Mar 11 20:50:53 MET 1999
 
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-
-    email                : kvoctrain@ewald-arnold.de
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2004-2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -34,8 +31,10 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kiconloader.h>
+#include <kprinter.h>
 
-#include <qinputdialog.h>
+#include <kinputdialog.h>
 #include <qtimer.h>
 
 #include <time.h>
@@ -44,17 +43,17 @@
 #include <kvoctraincore.h>
 #include "kvoctrain.h"
 #include "entry-dialogs/EntryDlg.h"
-#include "option-dialogs/GeneralOptionsDlg.h"
 #include "docprop-dialogs/DocPropDlg.h"
 #include "docprop-dialogs/DocPropLangDlg.h"
 #include "statistik-dialogs/StatistikDlg.h"
+#include "common-dialogs/kvoctrainprefs.h"
 #include "prefs.h"
 
-void kvoctrainApp::slotSaveOptions()
+/*void kvoctrainApp::slotSaveOptions()
 {
    saveOptions(true);
 }
-
+*/
 
 kvoctrainApp::~kvoctrainApp()
 {
@@ -75,7 +74,7 @@ void kvoctrainApp::slotCancelSelection ()
 void kvoctrainApp::slotSelectAll ()
 {
   QTableSelection ts;
-  RowTable *table = view->getTable();
+  KVocTrainTable *table = view->getTable();
   table->clearSelection();
   ts.init(0,0);
   ts.expandTo(table->numRows()-1, table->numCols()-1);
@@ -86,51 +85,42 @@ void kvoctrainApp::slotSelectAll ()
 void kvoctrainApp::slotCurrentCellChanged(int row, int col)
 {
   col -= KV_EXTRA_COLS;
+  bool noData = false;
+  kvoctrainExpr *expr;
 
   statusBar()->clear();
-  if (  doc->numEntries() <= row
-      ||doc->numLangs() <= col
-      || row < 0
-      || col < 0) {
-    if (rem_label != 0)
-      rem_label->setText  (i18n (PREFIX_Remark));
-    if (pron_label != 0)
-      pron_label->setText (i18n (PREFIX_Pronunce));
-    if (type_label != 0)
-      type_label->setText (i18n (PREFIX_Type));
-
-    if (entryDlg != 0) {
-      slotEditEntry(row, col+KV_EXTRA_COLS);
-      entryDlg->setEnabled(EntryDlg::EnableOnlyCommon);
-    }
-
-    return;
-  }
-
-  kvoctrainExpr *expr = doc->getEntry(row);
+  if (doc->numEntries() <= row || doc->numLangs() <= col || row < 0 || col < 0)
+    noData = true;
+  else
+    expr = doc->getEntry(row);
 
   if (rem_label != 0)
-    rem_label->setText( i18n(PREFIX_Remark) + expr->getRemark (col) );
+    rem_label->setText(i18n("Abbreviation for R)emark","R: %1")
+                       .arg(noData ? QString::null : expr->getRemark(col)));
   if (pron_label != 0)
-    pron_label->setText( i18n(PREFIX_Pronunce) + expr->getPronunce (col) );
+    pron_label->setText(i18n("Abbreviation for P)ronouncation","P: %1")
+                        .arg(noData ? QString::null : expr->getPronunce(col)));
   if (type_label != 0)
-    type_label->setText( i18n(PREFIX_Type)
-            + QueryManager::typeStr(expr->getType(col)) );
+    type_label->setText(i18n("Abbreviation for T)ype of word", "T: %1")
+                        .arg(noData ? QString::null : QueryManager::typeStr(expr->getType(col))));
 
   if (entryDlg != 0) {
-    if (col == 0)
-      entryDlg->setEnabled(EntryDlg::EnableOnlyOriginal);
-    else
-      entryDlg->setEnabled(EntryDlg::EnableAll);
-    slotEditEntry(row, col+KV_EXTRA_COLS);
+    if (noData)
+      entryDlg->setEnabled(EntryDlg::EnableOnlyCommon);
+    else {
+      if (col == 0)
+        entryDlg->setEnabled(EntryDlg::EnableOnlyOriginal);
+      else
+        entryDlg->setEnabled(EntryDlg::EnableAll);
+    }
+    slotEditEntry(row, col + KV_EXTRA_COLS);
   }
 }
 
 
 void kvoctrainApp::slotEditRow()
 {
-  slotEditEntry (view->getTable()->currentRow(),
-                 view->getTable()->currentColumn());
+  slotEditEntry (view->getTable()->currentRow(), view->getTable()->currentColumn());
 }
 
 
@@ -144,12 +134,14 @@ void kvoctrainApp::slotEditCallBack(int res)
 
     case EntryDlg::EditApply:
       commitEntryDlg(true);
-      if (smartAppend) {
+      if (Prefs::smartAppend())
+      {
         int row = view->getTable()->currentRow();
-        if (row == view->getTable()->numRows()-1) {
+        if (row == view->getTable()->numRows()-1)
+        {
           int col = view->getTable()->currentColumn();
-          if (   col < view->getTable()->numCols()-1
-              && col >= KV_COL_ORG ) {
+          if (col < view->getTable()->numCols()-1 && col >= KV_COL_ORG )
+          {
             int lesson = doc->getEntry(row)->getLesson();
             if (lesson >= lessons->count())
               lesson = QMAX (0, lessons->count()-1);
@@ -184,7 +176,7 @@ void kvoctrainApp::commitEntryDlg(bool force)
      return;
    }
 
-   if (!force && entryDlg->isModified() && !autoentryApply) {
+   if (!force && entryDlg->isModified() && !Prefs::autoEntryApply()) {
      if( KMessageBox::No == KMessageBox::warningYesNo(this,
                    i18n("The entry dialog contains unsaved changes.\n"
                         "Do you want to apply or discard your changes?"),
@@ -245,12 +237,13 @@ void kvoctrainApp::commitEntryDlg(bool force)
              QueryManager::getMainType(entryDlg->getType()) )
            expr->setType(j, entryDlg->getType());
      }
-     expr->setLesson (entryDlg->getLesson());
+     expr->setLesson(entryDlg->getLesson());
      expr->setActive(entryDlg->getActive());
 
      entryDlg->setModified(false);
      doc->setModified(true);
      view->getTable()->updateCell(row, col+KV_EXTRA_COLS);
+     view->getTable()->updateCell(row, KV_COL_LESS);
    }
    else {
      col -= KV_EXTRA_COLS;
@@ -363,7 +356,7 @@ void kvoctrainApp::createEntryDlg(int row, int col)
                     querymanager,
                     title,
                     doc->getEntry(row)->isActive(),
-                    ipafont);
+                    Prefs::iPAFont());
    }
    else {
      col -= KV_EXTRA_COLS;
@@ -415,13 +408,12 @@ void kvoctrainApp::createEntryDlg(int row, int col)
                     querymanager,
                     title,
                     doc->getEntry(row)->isActive(),
-                    ipafont);
+                    Prefs::iPAFont());
    }
    connect( entryDlg, SIGNAL(sigEditChoice(int)),
              this, SLOT(slotEditCallBack(int)));
 
-   opts_menu->setItemEnabled(ID_VIEW_INLINE, false);
-   view->getTable()->setEditorBlocked(true);
+   view->getTable()->setReadOnly(true);
 
    if (col == 0)
      entryDlg->setEnabled(EntryDlg::EnableOnlyOriginal);
@@ -430,7 +422,6 @@ void kvoctrainApp::createEntryDlg(int row, int col)
 
    vector<QTableSelection> tabsel;
    entryDlg->setCell(row, col+KV_EXTRA_COLS, tabsel);
-   entryDlg->initFocus();
    entryDlg->show();
 }
 
@@ -444,8 +435,7 @@ void kvoctrainApp::removeEntryDlg()
     entryDlg = 0;
   }
 
-  opts_menu->setItemEnabled(ID_VIEW_INLINE, true);
-  view->getTable()->setEditorBlocked(false);
+  view->getTable()->setReadOnly(false);
 }
 
 
@@ -576,6 +566,7 @@ void kvoctrainApp::setDataEntryDlg (int row, int col)
                        doc->getEntry(row)->isActive());
    }
    view->getTable()->updateCell(row, col);
+   view->getTable()->updateCell(row, KV_COL_LESS);
    vector<QTableSelection> tabsel;
    if (hasSel) {
      for (int i = 0; i < view->getTable()->numSelections(); ++i)
@@ -691,7 +682,6 @@ void kvoctrainApp::slotDocPropsLang ()
 void kvoctrainApp::slotModifiedDoc(bool mod)
 {
   setCaption(kapp->makeStdCaption(doc->getTitle(), false, doc->isModified()));
-  toolBar()->setItemEnabled(ID_FILE_SAVE, mod);
   slotStatusMsg(IDS_DEFAULT);
 }
 
@@ -708,25 +698,23 @@ bool kvoctrainApp::hasSelection()
 
 void kvoctrainApp::slotRemoveRow()
 {
-  view->setInlineEnabled(false);
-
   if (!hasSelection()) {
-    if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
+    if( KMessageBox::Continue == KMessageBox::warningContinueCancel(this,
                   i18n("Do you really want to delete the selected entry?\n"),
-                  kapp->makeStdCaption("")))
+                  kapp->makeStdCaption(""),KStdGuiItem::del()))
     {
-      RowTable *table = view->getTable();
+      KVocTrainTable *table = view->getTable();
       doc->removeEntry(table->currentRow());
       doc->setModified();
       table->updateContents();
     }
   }
   else {
-    if(KMessageBox::Yes == KMessageBox::questionYesNo(this,
+    if(KMessageBox::Continue == KMessageBox::warningContinueCancel(this,
                   i18n("Do you really want to delete the selected range?\n"),
-                  kapp->makeStdCaption("")))
+                  kapp->makeStdCaption(""),KStdGuiItem::del()))
     {
-      RowTable *table = view->getTable();
+      KVocTrainTable *table = view->getTable();
 
       int numRows = table->numRows();
       // Must count backwards otherwise entry-numbering goes wrong when
@@ -738,19 +726,23 @@ void kvoctrainApp::slotRemoveRow()
       table->updateContents();
     }
   }
-  view->setInlineEnabled(inline_edit);
+  editRemoveSelectedArea->setEnabled(view->getTable()->numRows() > 0);
 }
 
 
 void kvoctrainApp::slotAppendRow ()
 {
-    kvoctrainExpr expr;
-    expr.setLesson(act_lesson);
-    doc->appendEntry(&expr);
-    doc->setModified();
-    int row = doc->numEntries()-1;
-    view->getTable()->updateContents(row, KV_COL_ORG);
-    view->getTable()->setCurrentRow(row, KV_COL_ORG);
+  kvoctrainExpr expr;
+  expr.setLesson(act_lesson);
+  doc->appendEntry(&expr);
+  doc->setModified();
+  int row = doc->numEntries()-1;
+  view->getTable()->setRowHeight(row, view->getTable()->fontMetrics().lineSpacing() );
+  view->getTable()->setCurrentRow(row, KV_COL_ORG);
+  view->getTable()->updateContents(row, KV_COL_ORG);
+  view->getTable()->clearSelection();
+  view->getTable()->selectRow(row);
+  editRemoveSelectedArea->setEnabled(view->getTable()->numRows() > 0);
 }
 
 
@@ -880,7 +872,7 @@ void kvoctrainApp::slotCreateLesson(int header)
 
 void kvoctrainApp::slotShowStatist()
 {
-   StatistikDlg sdlg (langset, doc, &gradecols);
+   StatistikDlg sdlg (langset, doc);
    sdlg.exec();
 }
 
@@ -896,9 +888,10 @@ void kvoctrainApp::slotCleanVocabulary ()
    slotStatusMsg(IDS_DEFAULT);
 
    if (num != 0) {
-     view->setView(doc, langset, gradecols);
+     view->setView(doc, langset);
      QString s =
-        i18n("%1 entries with same content have been found and removed").arg(num);
+        i18n("1 entry with the same content has been found and removed.",
+             "%n entries with the same content have been found and removed.", num);
 
      KMessageBox::information(this,
        s,
@@ -910,14 +903,12 @@ void kvoctrainApp::slotCleanVocabulary ()
 void kvoctrainApp::slotCreateRandom()
 {
    bool ok = FALSE;
-   //shouldn't this dialog display the previous setting i.e Prefs::entriesPerLesson()?
-   int res = QInputDialog::getInteger(
-                i18n( "Entries in Lesson" ),
-                i18n( "Enter number of entries in lesson:" ), 1, 1, 1000, 1, &ok, this );
+   int res = KInputDialog::getInteger(i18n( "Entries in Lesson" ),
+                i18n( "Enter number of entries in lesson:" ), Prefs::entriesPerLesson(), 1, 1000, 1, &ok, this );
    if (!ok)
      return;
 
-   entriesPerLesson = res;
+   Prefs::setEntriesPerLesson(res);
 
    slotStatusMsg(i18n("Creating random lessons..."));
    QApplication::setOverrideCursor( waitCursor );
@@ -935,10 +926,10 @@ void kvoctrainApp::slotCreateRandom()
      s.setNum (less_no);
      s.insert (0, "- ");
      lessons->insertItem (s);
-     int less_cnt = entriesPerLesson;
+     int less_cnt = Prefs::entriesPerLesson();
      while (randomList.size () != 0) {
        if (--less_cnt <= 0) {
-         less_cnt = entriesPerLesson;
+         less_cnt = Prefs::entriesPerLesson();
          less_no++;
          s.setNum (less_no);
          s.insert (0, "- ");
@@ -969,73 +960,37 @@ void kvoctrainApp::slotGeneralOptions()
 
 void kvoctrainApp::slotGeneralOptionsPage(int index)
 {
-   QString defTrans;
-   GeneralOptionsDlg godlg (defTrans,
-                    separator,
-                    backupTime /(60*1000),
-                    langset,
-                    lastPixName,
-                    lessons,
-                    paste_order,
-                    useCurrent,
-                    doc,
-                    tablefont,
-                    ipafont,
-                    &querymanager,
-                    gradecols,
-                    header_resizer,
-                    smartAppend,
-                    autosaveopts,
-                    autoentryApply);
+  KVocTrainPrefs* dialog = new KVocTrainPrefs(langset, doc, lessons, &querymanager, this, "settings",  Prefs::self() );
+  connect(dialog, SIGNAL(settingsChanged()), this, SLOT(slotApplyPreferences()));
+  if (index >= 0)
+    dialog->selectPage(index);
+  dialog->show();
+}
 
-   if (index >= 0)
-     godlg.selectPage(index);
 
-   int res = godlg.exec();
-   if (res == QDialog::Accepted) {
+void kvoctrainApp::slotApplyPreferences()
+{
+  kdDebug() << "Prefs Update" << endl;
+  if (pron_label)
+    pron_label->setFont(Prefs::iPAFont());
+  view->getTable()->setFont(Prefs::tableFont());
+  view->getTable()->updateContents();
 
-      defTrans = godlg.getDefaultLang();
-      backupTime = godlg.getBackupTime()*60*1000;
-      smartAppend = godlg.getSmartAppend();
-      autosaveopts = godlg.getAutoSaveOpts();
-      autoentryApply = godlg.getAutoApply();
-      separator = godlg.getSeparator();
-      langset = godlg.getLangSet();
-      paste_order = godlg.getPasteOrder();
-      useCurrent = godlg.getUseCurrent(),
-      tablefont = godlg.getFont();
-      ipafont = godlg.getIPAFont();
-      gradecols = godlg.getGradeCols();
-      header_resizer = godlg.getResizer();
-
-       // rather ugly hack to keep useCurrent "globally" up to date
-      // is that necessary? anmma Feb 23rd 2004
-      Prefs::setUseCurrent( useCurrent);
-      Prefs::writeConfig();
-
-      if (pron_label)
-        pron_label->setFont(ipafont);
-      view->getTable()->setFont(tablefont);
-      view->setResizer (header_resizer);
-      view->getTable()->updateContents();
-
-      // update header buttons
-      for (int i = 0; i < (int) doc->numLangs(); i++) {
-        QString sid = i>0 ? doc->getIdent(i)
-                          : doc->getOriginalIdent();
-
-        int idx = langset.indexShortId(sid);
-        QString pm = "";
-        QString lid = sid;
-        if  (idx >= 0) {
-          lid = langset.longId(idx);
-          pm = langset.PixMapFile(idx);
-        }
-        view->setHeaderProp (i+KV_EXTRA_COLS, lid, pm);
-      }
-
-      slotStatusMsg(IDS_DEFAULT);
-   }
+  readLanguages();
+  // update header buttons
+  for (int i = 0; i < (int) doc->numLangs(); i++)
+  {
+    QString sid = i>0 ? doc->getIdent(i): doc->getOriginalIdent();
+    int idx = langset.indexShortId(sid);
+    QString pm = "";
+    QString lid = sid;
+    if (idx >= 0)
+    {
+      lid = langset.longId(idx);
+      pm = langset.PixMapFile(idx);
+    }
+    view->setHeaderProp(i + KV_EXTRA_COLS, lid, pm);
+  }
 }
 
 
@@ -1050,7 +1005,7 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
                         "Should this dialog be invoked now?");
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
                   msg,
-                  kapp->makeStdCaption("")));
+                  kapp->makeStdCaption(""),i18n("Invoke Dialog"), i18n("Do Not Invoke")))
      {
        slotGeneralOptionsPage(1);
      }
@@ -1059,7 +1014,6 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
 
    if (lang_id >= (int) langset.size())
      return;
-
    doc->appendLang("");
    int num = doc->numEntries()-1;
    for (int i = 0; i < (int) num; i++) {
@@ -1068,7 +1022,7 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
    }
 
    doc->setIdent(doc->numLangs()-1, langset.shortId(lang_id));
-   view->setView(doc, langset, gradecols);
+   view->setView(doc, langset);
    doc->setModified();
 }
 
@@ -1105,12 +1059,14 @@ void kvoctrainApp::slotResumeSearch(const QString& s)
   bool word_beg = controlActive;
   int idx = doc->search(s, view->getTable()->currentColumn()-KV_EXTRA_COLS, searchpos, -1, word_beg, false);
   if (idx >= 0) {
+    view->getTable()->clearSelection();
     view->getTable()->setCurrentRow(idx, view->getTable()->currentColumn());
     searchpos = idx+1;
   }
   else { // try again from beginning up to current pos
     int idx = doc->search(s, view->getTable()->currentColumn()-KV_EXTRA_COLS, 0, searchpos, word_beg, false);
     if (idx >= 0) {
+      view->getTable()->clearSelection();
       view->getTable()->setCurrentRow(idx, view->getTable()->currentColumn());
       searchpos = idx+1;
     }
@@ -1123,51 +1079,10 @@ void kvoctrainApp::slotResumeSearch(const QString& s)
   slotStatusMsg(IDS_DEFAULT);
 }
 
-void kvoctrainApp::slotViewToolBar()
-{
-  ///////////////////////////////////////////////////////////////////
-  // turn Toolbar on or off
-  bViewToolbar=!bViewToolbar;
-  menuBar()->setItemChecked(ID_VIEW_TOOLBAR, bViewToolbar);
-  if (bViewToolbar)
-     toolBar()->show();
-  else
-     toolBar()->hide();
-  slotStatusMsg(IDS_DEFAULT);
-}
-
-
-void kvoctrainApp::slotViewInline()
-{
-  inline_edit = !inline_edit;
-  menuBar()->setItemChecked(ID_VIEW_INLINE, inline_edit);
-  view->setInlineEnabled(inline_edit);
-  slotStatusMsg(IDS_DEFAULT);
-}
-
-
-void kvoctrainApp::slotViewStatusBar()
-{
-  ///////////////////////////////////////////////////////////////////
-  //turn Statusbar on or off
-  bViewStatusbar=!bViewStatusbar;
-  menuBar()->setItemChecked(ID_VIEW_STATUSBAR, bViewStatusbar);
-  if (bViewStatusbar)
-    statusBar()->show();
-  else
-    statusBar()->hide();
-  slotStatusMsg(IDS_DEFAULT);
-}
-
 
 void kvoctrainApp::slotStatusMsg(const QString &/*text*/)
 {
-/*
-  ///////////////////////////////////////////////////////////////////
-  // change status message permanently
-  statusBar()->clear();
-  statusBar()->changeItem(text, ID_STATUS_MSG );
-*/
+//
 }
 
 
@@ -1199,21 +1114,21 @@ void kvoctrainApp::aboutToShowLearn()
     int j;
     header_m = new QPopupMenu();
     if (header != 0 ) {
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create Random &Query"), (header << 16) | IDH_START_QUERY);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), (header << 16) | IDH_START_MULTIPLE);
+      header_m->insertItem(SmallIconSet("run_query"), i18n("Create Random &Query"), (header << 16) | IDH_START_QUERY);
+      header_m->insertItem(SmallIconSet("run_multi"), i18n("Create &Multiple Choice"), (header << 16) | IDH_START_MULTIPLE);
 
       header_m->setItemEnabled((header << 16) | IDH_START_MULTIPLE, doc->numLangs() > 1);
       header_m->setItemEnabled((header << 16) | IDH_START_QUERY,  doc->numLangs() > 1);
       header_m->insertSeparator();
 
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("&Verbs"), (header << 16) | IDH_START_VERB);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Articles"), (header << 16) | IDH_START_ARTICLE);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison Forms"), (header << 16) | IDH_START_ADJECTIVE);
+      header_m->insertItem(i18n("&Verbs"), (header << 16) | IDH_START_VERB);
+      header_m->insertItem(i18n("&Articles"), (header << 16) | IDH_START_ARTICLE);
+      header_m->insertItem(i18n("&Comparison Forms"), (header << 16) | IDH_START_ADJECTIVE);
       header_m->insertSeparator();
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-syno.xpm")), i18n("S&ynonyms"), (header << 16) | IDH_START_SYNONYM);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-anto.xpm")), i18n("A&ntonyms"), (header << 16) | IDH_START_ANTONYM);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-exmp.xpm")), i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-para.xpm")), i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
+      header_m->insertItem(i18n("S&ynonyms"), (header << 16) | IDH_START_SYNONYM);
+      header_m->insertItem(i18n("A&ntonyms"), (header << 16) | IDH_START_ANTONYM);
+      header_m->insertItem(i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
+      header_m->insertItem(i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
     }
     else {
       QPopupMenu *query_m =  new QPopupMenu();
@@ -1225,15 +1140,15 @@ void kvoctrainApp::aboutToShowLearn()
         if((j = langset.indexShortId(doc->getIdent(i))) >= 0
            && !langset.PixMapFile(j).isEmpty()
            && !langset.longId(j).isEmpty() ) {
-          query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(main_names[i]),
+          query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("From %1").arg(main_names[i]),
               (i << (16+8)) |  IDH_START_QUERY);  // hack: IDs => header-ids + cmd
         }
         else {
-          query_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
+          query_m->insertItem(i18n("From %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
         }
       }
 
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create Random &Query"), query_m, (3 << 16) | IDH_NULL);
+      header_m->insertItem(SmallIconSet("run_query"), i18n("Create Random &Query"), query_m, (3 << 16) | IDH_NULL);
       connect (query_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
       connect (query_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
 
@@ -1243,24 +1158,24 @@ void kvoctrainApp::aboutToShowLearn()
         if((j = langset.indexShortId(doc->getIdent(i))) >= 0
            && !langset.PixMapFile(j).isEmpty()
            && !langset.longId(j).isEmpty() ) {
-          multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(main_names[i]),
+          multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("From %1").arg(main_names[i]),
               (i << (16+8)) |  IDH_START_MULTIPLE);  // hack: IDs => header-ids + cmd
         }
         else {
-          multiple_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
+          multiple_m->insertItem(i18n("From %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
         }
       }
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
+      header_m->insertItem(SmallIconSet("run_multi"), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
       header_m->insertSeparator();
 
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("Train &Verbs"), (header << 16) | IDH_START_VERB);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Article Training"), (header << 16) | IDH_START_ARTICLE);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison Training"), (header << 16) | IDH_START_ADJECTIVE);
+      header_m->insertItem(i18n("Train &Verbs"), (header << 16) | IDH_START_VERB);
+      header_m->insertItem(i18n("&Article Training"), (header << 16) | IDH_START_ARTICLE);
+      header_m->insertItem(i18n("&Comparison Training"), (header << 16) | IDH_START_ADJECTIVE);
       header_m->insertSeparator();
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-syno.xpm")), i18n("&Synonyms"), (header << 16) | IDH_START_SYNONYM);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-anto.xpm")), i18n("&Antonyms"), (header << 16) | IDH_START_ANTONYM);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-exmp.xpm")), i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
-      header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-para.xpm")), i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
+      header_m->insertItem(i18n("&Synonyms"), (header << 16) | IDH_START_SYNONYM);
+      header_m->insertItem(i18n("&Antonyms"), (header << 16) | IDH_START_ANTONYM);
+      header_m->insertItem(i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
+      header_m->insertItem(i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
 
       connect (multiple_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
       connect (multiple_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
@@ -1282,77 +1197,75 @@ void kvoctrainApp::aboutToShowLearn()
   }
 
   learn_menu->insertSeparator();
-  learn_menu->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Resume &Query"), ID_RESUME_QUERY );
-  learn_menu->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Resume &Multiple Choice"), ID_RESUME_MULTIPLE );
+  learn_menu->insertItem(SmallIconSet("run_query"), i18n("Resume &Query"), ID_RESUME_QUERY );
+  learn_menu->insertItem(SmallIconSet("run_multi"), i18n("Resume &Multiple Choice"), ID_RESUME_MULTIPLE );
 
   learn_menu->setItemEnabled(ID_RESUME_QUERY,  query_num != 0);
   learn_menu->setItemEnabled(ID_RESUME_MULTIPLE,  query_num != 0);
 
 }
 
-
-void kvoctrainApp::aboutToShowOptions()
+void kvoctrainApp::aboutToShowVocabAppendLanguage()
 {
-  opts_menu->setItemEnabled(ID_SAVE_OPTIONS, !autosaveopts);
+  if (doc != 0)
+  {
+    vocabAppendLanguage->clear();
+    QPopupMenu * add_m = vocabAppendLanguage->popupMenu();
+
+    QStringList names;
+    for (int i = 0; i < (int) langset.size(); i++)
+    {
+      if(langset.longId(i).isEmpty() )
+        names.append(langset.shortId(i));
+      else
+        names.append(langset.longId(i));
+    }
+
+    for (int i = 0; i < (int) langset.size(); i++)
+    {
+      if(!langset.PixMapFile(i).isEmpty() && !langset.longId(i).isEmpty())
+        add_m->insertItem(QPixmap(langset.PixMapFile(i)), names[i], (i << 16) | IDH_APPEND);
+      else
+        add_m->insertItem(names[i], (i << 16) | IDH_APPEND);
+    }
+
+    add_m->insertItem(i18n("Another Language..."), (0xFF << 16) | IDH_APPEND);
+  }
 }
 
 
-void kvoctrainApp::aboutToShowVocabulary() {
-//  voc_menu->setItemEnabled(ID_RESUME_QUERY,  query_num != 0);
+void kvoctrainApp::aboutToShowVocabSetLanguage()
+{
+  if (doc != 0)
+  {
+    vocabSetLanguage->clear();
+    QPopupMenu * set_m = vocabSetLanguage->popupMenu();
 
-  if (doc != 0) {
-    int pos = voc_menu->indexOf(ID_APPEND_LANG);
-    voc_menu->removeItem (ID_APPEND_LANG);
-    vector<QString> names;
-
-    QPopupMenu *add_m = new QPopupMenu();
-
-    for (int i = 0; i < (int) langset.size(); i++) {
+    QStringList names;
+    for (int i = 0; i < (int) langset.size(); i++)
+    {
       if(langset.longId(i).isEmpty() )
-        names.push_back(langset.shortId(i));
+        names.append(langset.shortId(i));
       else
-        names.push_back(langset.longId(i));
+        names.append(langset.longId(i));
     }
 
-    for (int i = 0; i < (int) langset.size(); i++) {
-      if(   !langset.PixMapFile(i).isEmpty()
-         && !langset.longId(i).isEmpty() )
-        add_m->insertItem(QPixmap(langset.PixMapFile(i)), names[i],
-          (i << 16) | IDH_APPEND);
-      else
-        add_m->insertItem(names[i],
-          (i << 16) | IDH_APPEND);
-    }
-    add_m->insertItem(i18n("Another Language..."), (0xFF << 16) | IDH_APPEND);
-
-    connect (add_m, SIGNAL(activated(int)), this, SLOT(slotAppendLang(int)));
-    connect (add_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
-
-    voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/append-col.xpm")),
-                   i18n("&Append Language"), add_m, ID_APPEND_LANG,
-                   pos);
-
-
-    pos = voc_menu->indexOf(ID_SET_LANG);
-    voc_menu->removeItem (ID_SET_LANG);
-    QPopupMenu *set_m = new QPopupMenu();
-
-    for (int header = 0; header < doc->numLangs(); ++header ) {
+    for (int header = 0; header < doc->numLangs(); ++header )
+    {
       // select one of the available languages for the column
       QPopupMenu *langs_m = new QPopupMenu();
-      // hack: ID => header-id + language
+        // hack: ID => header-id + language
 
       for (int i = 0; i < (int) langset.size(); i++) {
-        if(   !langset.PixMapFile(i).isEmpty()
-           && !langset.longId(i).isEmpty() )
-          langs_m->insertItem(QPixmap(langset.PixMapFile(i)), names[i],
-            (header << 16) | (i << (16+8)) | IDH_SET_LANG);
+        if(!langset.PixMapFile(i).isEmpty() && !langset.longId(i).isEmpty())
+          langs_m->insertItem(QPixmap(langset.PixMapFile(i)), names[i], (header << 16) | (i << (16+8)) | IDH_SET_LANG);
         else
-          langs_m->insertItem(names[i],
-            (header << 16) | (i << (16+8)) | IDH_SET_LANG);
+          langs_m->insertItem(names[i], (header << 16) | (i << (16+8)) | IDH_SET_LANG);
       }
+
       connect (langs_m, SIGNAL(activated(int)), this, SLOT(slotSetHeaderProp(int)));
       connect (langs_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
+
       if (header == 0)
         set_m->insertItem(i18n("&Original"), langs_m, (2 << 16) | IDH_NULL);
       else {
@@ -1362,42 +1275,38 @@ void kvoctrainApp::aboutToShowVocabulary() {
           set_m->insertItem(i18n("&%1. Translation").arg(header), langs_m, (2 << 16) | IDH_NULL);
       }
     }
-    voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")),
-                   i18n("Set &Language"), set_m, ID_SET_LANG,
-                   pos);
+  }
+}
 
 
+void kvoctrainApp::aboutToShowVocabRemoveLanguage()
+{
+  if (doc != 0)
+  {
+    vocabRemoveLanguage->clear();
+    QPopupMenu * remove_m = vocabRemoveLanguage->popupMenu();
 
-    pos = voc_menu->indexOf(ID_REMOVE_LANG);
-    voc_menu->removeItem (ID_REMOVE_LANG);
-    QPopupMenu *remove_m = new QPopupMenu();
-    names.clear();
-    for (int j = 1; j < (int) doc->numLangs(); j++) {
-     int i;
-     if ((i = langset.indexShortId(doc->getIdent(j))) >= 0)
-       names.push_back(langset.longId(i));
-     else
-       names.push_back(doc->getIdent(j));
+    QStringList names;
+    for (int j = 1; j < (int) doc->numLangs(); j++)
+    {
+      int i;
+      if ((i = langset.indexShortId(doc->getIdent(j))) >= 0)
+        names.append(langset.longId(i));
+      else
+        names.append(doc->getIdent(j));
     }
 
-    for (int i = 1; i < (int) doc->numLangs(); i++) {
+    for (int i = 1; i < (int) doc->numLangs(); i++)
+    {
       // show pixmap and long name if available
       int j;
       if((j = langset.indexShortId(doc->getIdent(i))) >= 0
-         && !langset.PixMapFile(j).isEmpty()
-         && !langset.longId(j).isEmpty() ) {
-        remove_m->insertItem(QPixmap(langset.PixMapFile(j)), names[i-1],
-            (i << 16) |  IDH_REMOVE);  // hack: IDs => header-ids + cmd
-      }
-      else {
+          && !langset.PixMapFile(j).isEmpty()
+          && !langset.longId(j).isEmpty() )
+        remove_m->insertItem(QPixmap(langset.PixMapFile(j)), names[i-1], (i << 16) |  IDH_REMOVE);  // hack: IDs => header-ids + cmd
+      else
         remove_m->insertItem(doc->getIdent(i), (i << 16) | IDH_REMOVE);
-      }
     }
-    voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/delete-col.xpm")),
-                   i18n("&Remove Language"), remove_m, ID_REMOVE_LANG,
-                   pos);
-    connect (remove_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
-    connect (remove_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
   }
 }
 
@@ -1410,87 +1319,17 @@ void kvoctrainApp::slotStatusHelpMsg(const QString &text)
     statusBar()->message(text, 3000);
 }
 
-
-void kvoctrainApp::commandCallback(int id_){
-  id_ &=0xffff;
-  switch (id_){
-    ON_CMD(ID_FILE_NEW,                 slotFileNew())
-    ON_CMD(ID_FILE_OPEN,                slotFileOpen())
-    ON_CMD(ID_FILE_OPEN_XMP,            slotFileOpenExample())
-    ON_CMD(ID_FILE_MERGE,               slotFileMerge())
-    ON_CMD(ID_FILE_SAVE,                slotFileSave())
-    ON_CMD(ID_FILE_SAVE_AS,             slotFileSaveAs())
-
-    ON_CMD(ID_FILE_QUIT,                slotFileQuit())
-
-    ON_CMD(ID_EDIT_COPY,                slotEditCopy())
-    ON_CMD(ID_EDIT_PASTE,               slotEditPaste())
-    ON_CMD(ID_SEARCH_CLIP,              slotSmartSearchClip())
-    ON_CMD(ID_APPEND_ROW,               slotAppendRow())
-    ON_CMD(ID_REMOVE_ROW,               slotRemoveRow())
-    ON_CMD(ID_EDIT_ROW,                 slotEditRow())
-    ON_CMD(ID_CLR_SEL,                  slotCancelSelection())
-    ON_CMD(ID_SEL_ALL,                  slotSelectAll())
-    ON_CMD(ID_SAVE_ROW,                 slotSaveSelection())
-
-//    ON_CMD(ID_APPEND_LANG,              slotAppendLang())
-    ON_CMD(ID_DOC_PROPS,                slotDocProps())
-    ON_CMD(ID_DOC_PROPS_LANG,           slotDocPropsLang())
-    ON_CMD(ID_GENERAL_OPTIONS,          slotGeneralOptions())
-    ON_CMD(ID_QUERY_OPTIONS,            slotQueryOptions())
-    ON_CMD(ID_SHOW_STAT,                slotShowStatist())
-    ON_CMD(ID_RAND_CREATE,              slotCreateRandom())
-    ON_CMD(ID_CLEANUP,                  slotCleanVocabulary())
-//    ON_CMD(ID_RESUME_QUERY,             slotTimeOutRandomQuery())
-//    ON_CMD(ID_RESUME_MULTIPLE,          slotTimeOutMultipleChoice())
-
-    ON_CMD(ID_VIEW_INLINE,              slotViewInline())
-    ON_CMD(ID_VIEW_TOOLBAR,             slotViewToolBar())
-    ON_CMD(ID_VIEW_STATUSBAR,           slotViewStatusBar())
-    ON_CMD(ID_SAVE_OPTIONS,             slotSaveOptions())
+void kvoctrainApp::slotFilePrint()
+{
+  slotStatusMsg(i18n("Printing..."));
+  KPrinter printer;
+  printer.setFullPage(true);
+  if (printer.setup(this))
+  {
+    view->print(&printer);
   }
-}
 
-
-void kvoctrainApp::statusCallback(int id_){
-  id_ &= 0xffff;
-  switch (id_){
-    ON_STATUS_MSG(ID_FILE_NEW,          i18n("Creates a new document"))
-    ON_STATUS_MSG(ID_FILE_OPEN,         i18n("Opens an existing document"))
-    ON_STATUS_MSG(ID_FILE_OPEN_XMP,     i18n("Opens an example document from the KVocTrain package"))
-    ON_STATUS_MSG(ID_FILE_OPEN_RECENT,  i18n("Opens one of your recent documents"))
-    ON_STATUS_MSG(ID_FILE_MERGE,        i18n("Merges an existing document to the current vocabulary"))
-    ON_STATUS_MSG(ID_FILE_SAVE,         i18n("Saves the current document"))
-    ON_STATUS_MSG(ID_FILE_SAVE_AS,      i18n("Saves the document as..."))
-    ON_STATUS_MSG(ID_FILE_QUIT,         i18n("Exits the program"))
-
-    ON_STATUS_MSG(ID_EDIT_COPY,         i18n("Copies the selected section to the clipboard"))
-    ON_STATUS_MSG(ID_EDIT_PASTE,        i18n("Pastes the clipboard contents to the end"))
-    ON_STATUS_MSG(ID_SEARCH_CLIP,       i18n("Searches clipboard contents in vocabulary"))
-    ON_STATUS_MSG(ID_APPEND_ROW,        i18n("Appends new entry to vocabulary"))
-    ON_STATUS_MSG(ID_REMOVE_ROW,        i18n("Removes selected entries from the vocabulary"))
-    ON_STATUS_MSG(ID_EDIT_ROW,          i18n("Edits properties of current selection"))
-    ON_STATUS_MSG(ID_SAVE_ROW,          i18n("Writes selected rows to a file"))
-    ON_STATUS_MSG(ID_SEL_ALL,           i18n("Selects all entries"))
-    ON_STATUS_MSG(ID_CLR_SEL,           i18n("Deselects all entries"))
-
-    ON_STATUS_MSG(ID_VIEW_TOOLBAR,      i18n("Enables/disables the current toolbar"))
-    ON_STATUS_MSG(ID_VIEW_STATUSBAR,    i18n("Enables/disables the statusbar"))
-    ON_STATUS_MSG(ID_VIEW_INLINE,       i18n("Enables/disables inline editing in the table view"))
-    ON_STATUS_MSG(ID_SAVE_OPTIONS,      i18n("Saves options"))
-    ON_STATUS_MSG(ID_DOC_PROPS,         i18n("Edits document properties"))
-    ON_STATUS_MSG(ID_DOC_PROPS_LANG,    i18n("Edits language properties in current document"))
-
-//    ON_STATUS_MSG(ID_APPEND_LANG,       i18n("Appends a column for a new language to the table"))
-    ON_STATUS_MSG(ID_GENERAL_OPTIONS,   i18n("Shows general options dialog"))
-    ON_STATUS_MSG(ID_QUERY_OPTIONS,     i18n("Shows query options dialog"))
-    ON_STATUS_MSG(ID_SEARCH,            i18n("Enters smart search mode"))
-    ON_STATUS_MSG(ID_SHOW_STAT,         i18n("Shows statistics"))
-    ON_STATUS_MSG(ID_RAND_CREATE,       i18n("Creates random lessons with unassigned entries"))
-    ON_STATUS_MSG(ID_CLEANUP,           i18n("Removes entries with same content from vocabulary"))
-//    ON_STATUS_MSG(ID_RESUME_QUERY,      i18n("Resumes random query with existing selection"))
-//    ON_STATUS_MSG(ID_RESUME_MULTIPLE,   i18n("Resumes multiple choice with existing selection"))
-  }
+  slotStatusMsg(i18n("Ready"));
 }
 
 #include "kvoctrain.moc"
