@@ -330,12 +330,10 @@ bool QueryManager::validate(kvoctrainExpr *expr, int act_lesson, int idx, QueryT
 
    if (compareLesson ((CompType) Prefs::compType(Prefs::EnumType::Lesson), expr->getLesson(),
                       lessonitems, act_lesson)
-       && type_ok) {
+       && type_ok)
      return true;
-     }
-   else {
-     return false;
-   }
+
+   return false;
 }
 
 
