@@ -1,13 +1,11 @@
 /***************************************************************************
 
-    $Id: kvd_lex.cpp,v 1.9 2003/07/17 12:48:21 binner Exp $
-
             maintain a *.lex document (vocabulary trainer for Win)
 
     -----------------------------------------------------------------------
 
     begin                : Sat Sep 04 11:00:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
     email                : kvoctrain@ewald-arnold.de
@@ -30,9 +28,7 @@
 #include <kmessagebox.h>
 
 #include "kvoctraindoc.h"
-#include "kvoctraincore.h"
 
-#include <qtextstream.h>
 
 #include <vector>
 using namespace std;
@@ -87,7 +83,7 @@ Sachgebiete|
 |
 |
 |
-32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 
+32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32 32
 1 0 255 255 255 255 255 255 0 0 1 Abbildung||||mapping||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
 1 0 255 255 255 255 255 255 0 0 1 Abblendkappe||||anti-dazzle device||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
 ...
@@ -180,7 +176,7 @@ bool kvoctrainDoc::loadLessonLex (QTextStream &is)
 }
 
 
-bool kvoctrainDoc::saveToLex (QTextStream& os, QString &title)
+bool kvoctrainDoc::saveToLex (QTextStream& os, QString & /*title*/)
 {
   os << LEX_IDENT_50 "\n";
   os << "LEX|" << getOriginalIdent() << "|" << getIdent(1) << "|"
@@ -220,7 +216,7 @@ bool kvoctrainDoc::saveToLex (QTextStream& os, QString &title)
 
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, ent_no / f_ent_percent);
+      emit progressChanged(this, int(ent_no / f_ent_percent));
 
     os << "0" // type
        <<  " " << "255 255 255 255 255 255 255"
@@ -335,7 +331,7 @@ bool kvoctrainDoc::loadFromLex (QTextStream& is)
 
   for (int i = 0; !is.eof() && i < lines; i++) {
     if (ent_percent != 0 && (i % ent_percent) == 0 ) {
-      emit progressChanged(this, i / f_ent_percent);
+      emit progressChanged(this, int(i / f_ent_percent));
     }
 
     is >> type;
@@ -388,7 +384,7 @@ bool kvoctrainDoc::loadFromLex (QTextStream& is)
 }
 
 
-void kvoctrainDoc::errorLex (int line, const QString &text )
+void kvoctrainDoc::errorLex (int /*line*/, const QString &text )
 {
    unknown_elem = true;
    QApplication::setOverrideCursor( arrowCursor, true );
