@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: kvd_rb_kvtml1.cpp 356998 2004-10-23 00:54:18Z hedlund $
-
                      read big body of a kvtml document
 
     -----------------------------------------------------------------------
@@ -21,7 +19,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -795,7 +793,7 @@ bool kvoctrainDoc::parseBody_kvtml (XmlElement elem, XmlReader& xml)
       if (lines != 0) {
         ent_no++;
         if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-          emit progressChanged(this, ent_no / f_ent_percent);
+          emit progressChanged(this, int(ent_no / f_ent_percent));
       }
       if (!parseBody_e (elem, xml)) return false;
     }
