@@ -81,12 +81,12 @@ public:
 	ExtDate addYears( int years ) const;
 	int daysTo( const ExtDate & ) const;
 
-	bool operator==( const ExtDate &d ) const { return m_jd == d.jd(); };
-	bool operator!=( const ExtDate &d ) const { return m_jd != d.jd(); };
-	bool operator<( const ExtDate &d )  const { return m_jd  < d.jd(); };
-	bool operator<=( const ExtDate &d ) const { return m_jd <= d.jd(); };
-	bool operator>( const ExtDate &d )  const { return m_jd  > d.jd(); };
-	bool operator>=( const ExtDate &d ) const { return m_jd >= d.jd(); };
+	bool operator==( const ExtDate &d ) const { return m_jd == d.jd(); }
+	bool operator!=( const ExtDate &d ) const { return m_jd != d.jd(); }
+	bool operator<( const ExtDate &d )  const { return m_jd  < d.jd(); }
+	bool operator<=( const ExtDate &d ) const { return m_jd <= d.jd(); }
+	bool operator>( const ExtDate &d )  const { return m_jd  > d.jd(); }
+	bool operator>=( const ExtDate &d ) const { return m_jd >= d.jd(); }
 
 	static ExtDate currentDate( Qt::TimeSpec ts = Qt::LocalTime );
 #ifndef QT_NO_DATESTRING
@@ -113,7 +113,7 @@ private:
 
 	friend class ExtDateTime;
 
-	#ifndef QT_NO_DATASTREAM
+#ifndef QT_NO_DATASTREAM
 	friend Q_EXPORT QDataStream &operator<<( QDataStream &, const ExtDate & );
 	friend Q_EXPORT QDataStream &operator>>( QDataStream &, ExtDate & );
 	friend Q_EXPORT QDataStream &operator<<( QDataStream &, const ExtDateTime & );
